#
# spec file for package yakuake
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without released
Name:           yakuake
Version:        22.12.3
Release:        bp155.1.5
Summary:        Drop-down terminal emulator based on Konsole technologies
License:        GPL-2.0-or-later
URL:            https://apps.kde.org/yakuake
Source:         https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  fdupes
%if 0%{?suse_version} < 1550
# c++-20 required
BuildRequires:  gcc10-PIE
BuildRequires:  gcc10-c++
%endif
BuildRequires:  kf5-filesystem
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5Archive)
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5Crash)
BuildRequires:  cmake(KF5DBusAddons)
BuildRequires:  cmake(KF5GlobalAccel)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5IconThemes)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5NewStuff)
BuildRequires:  cmake(KF5Notifications)
BuildRequires:  cmake(KF5NotifyConfig)
BuildRequires:  cmake(KF5Parts)
BuildRequires:  cmake(KF5Wayland)
BuildRequires:  cmake(KF5WidgetsAddons)
BuildRequires:  cmake(KF5WindowSystem)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5X11Extras)
Requires:       konsole-part > 15.12
Recommends:     konsole > 15.12

%description
Yakuake is a Drop-down terminal emulator based on Konsole technologies.

%lang_package

%prep
%autosetup -p1

%build
%if 0%{?suse_version} < 1550
  export CXX=g++-10
%endif
%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build
%suse_update_desktop_file -G "Terminal Program" org.kde.yakuake System TerminalEmulator

%find_lang %{name}

%fdupes -s %{buildroot}

%files
%license LICENSES/*
%doc README.md AUTHORS ChangeLog NEWS
%{_kf5_applicationsdir}/org.kde.yakuake.desktop
%{_kf5_appstreamdir}/org.kde.yakuake.appdata.xml
%{_kf5_bindir}/yakuake
%{_kf5_knsrcfilesdir}/yakuake.knsrc
%dir %{_kf5_iconsdir}/hicolor/256x256
%dir %{_kf5_iconsdir}/hicolor/256x256/apps
%{_kf5_iconsdir}/hicolor/*/apps/yakuake.*
%{_kf5_notifydir}/
%{_kf5_sharedir}/yakuake/
%{_kf5_sharedir}/dbus-1/services/org.kde.yakuake.service

%files lang -f %{name}.lang

%changelog
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Changes since 21.12.3:
  * Fix Slide effect on Wayland (kde#447456)
  * Tag as DBusActivatable
  * It's by default in ecm
  * Make it compile against last kf
  * Use nullptr
  * Use std::as_const here
  * Fix compile against last kf5.89
  * Use nullptr
  * Make sure position is always set in wayland (kde#408468)
  * Make it compile without deprecated methods
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- No code change since 21.12.2
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- No code change since 21.12.1
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- Changes since 21.12.0:
  * Wayland: don't block on a response from plasmashell before toggling
  * Make sure position is always set in wayland (kde#408468)
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- No code change since 21.11.90
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- No code change since 21.11.80
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80
  * New feature release
- Changes since 21.08.3:
  * Use QGuiApplication::focusWindowChanged instead of KWindowSystem::activeWindowChanged (kde#380497)
  * Add Linux CI
  * Add kde-ci.yml
  * Fix mem leak
  * We depend against kf5 5.82
  * Port deprecated method
* Tue Nov  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.3/
- No code change since 21.08.2
* Tue Oct  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.2/
- No code change since 21.08.1
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.1
- No code change since 21.08.0
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.0
- No code change since 21.07.90
* Fri Jul 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.90
  * New feature release
- Changes since 21.07.80:
  * Tell cmake our version
* Sat Jul 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.80
  * New feature release
- Changes since 21.04.3:
  * Allow switching the terminals in split view with CTRL+TAB
  * Increase cmake and deps versions
  * Build without Qt deprecations
  * Port to QElapsedTimer
  * Port away from deprecated QList methods
  * Port various Qt deprecations
  * Fix KF deprecations
  * Fix clazy warnings
  * Fix Yakuake icon appearing in taskbar through
    Qt::Tool window flag (kde#360037)
* Wed Jul  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.3
- No code change since 21.04.2
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.2
- No code change since 21.04.1
* Wed May 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/21.04.1
- No code change since 21.04.0
* Fri Apr 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04
- No code change since 21.03.90
* Fri Apr  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.90
  * New feature release
- No code change since 21.03.80
* Sun Mar 21 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.80
  * New feature release
- Too many changes to list here.
* Thu Mar  4 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/20.12.3
- No code change since 20.12.2
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-02-apps-update
- No code change since 20.12.1
* Tue Jan  5 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-01-apps-update
- No code change since 20.12.0
* Sat Dec  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-12-apps-update
- No code change since 20.11.90
* Fri Nov 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.90
  * New feature release
- No code change since 20.11.80
* Sat Nov 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.80
  * New feature release
- Changes since 20.08.3:
  * Consider renaming tabs via DBus interactive. This
    allows it to override a previouly interactively set title. (kde#428400)
  * Fix deprecated knsrc file location
  * Fix fullscreen mode regression (kde#424286)
* Thu Nov  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-11-apps-update
- Changes since 20.08.2:
  * Consider renaming tabs via DBus interactive. This allows it
    to override a previouly interactively set title. (kde#428400)
* Fri Oct  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-10-apps-update
- No code change since 20.08.1
* Tue Sep  1 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-09-apps-update
- No code change since 20.08.0
* Sun Aug  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-08-apps-update
- No code change since 20.07.90
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.90
  * New feature release
- Changes since 20.07.80:
  * Fix fullscreen mode regression (kde#424286)
* Sun Jul 19 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.80
  * New feature release
- Too many changes since 20.04.3, only listing bugfixes:
  * Show a warning notification if Konsole is outdated (kde#422187)
  * Make it possible to configure the konsolepart shortcuts (kde#412496)
  * Add option to toggle the systray icon (kde#423408)
  * Reraise the active sesson after renaming a session (kde#408374)
  * Prevent incorrect terminal switching (kde#421632)
* Thu Jul  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-07-apps-update
- Changes since 20.04.2:
  * Fix maximization behaviour (kde#414049)
  * Fix shortcut conflict for session closing (kde#319172)
* Tue Jun  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-06-apps-update
- No code change since 20.04.1
* Fri May 15 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-05-apps-update
- No code change since 20.04.0
* Thu Apr 23 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-04-apps-update
- No code change since 20.03.90
* Sun Apr  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.90
  * New feature release
- No code change since 20.03.80
* Sun Mar 22 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.80
  * New feature release
- Changes since 19.12.3:
  * Add support for resizing by dragging the title bar
  * Support opening new sessions in current working dir (kde#396472)
  * It alreadys added by kaboutdata
  * Port deprecated methods
  * Use URLs with transport encryption
* Thu Mar  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-03-apps-update
- Changes since 19.12.2:
  * appdata: use canonical cdn screenshot location
* Fri Feb  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Wed Feb  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-02-apps-update
- No code change since 19.12.1
* Tue Jan  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12.1
- No code change since 19.12.0
* Tue Dec 10 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12
- Changes since 19.11.90:
  * Port away from deprecated overload of slideWindow
* Sat Nov 30 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/19.12-rc
- Changes since 19.11.80:
  * Enable high DPI pixmaps (kde#407726)
* Sun Nov 24 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.80
  * New feature release
- Changes since 19.08.3:
  * Minor qstring optimization + use isEmpty
  * Get rid of deprecated qSort(), qFind(), and screenCount()
* Thu Nov  7 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.3.php
- No code change since 19.08.2
* Fri Oct 11 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.2.php
- No code change since 19.08.1
* Thu Sep  5 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.1.php
- No code change since 19.08.0
* Fri Aug  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.0.php
- No code change since 19.07.90
* Tue Aug  6 2019 lbeltrame@kde.org
- Update to 19.07.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-rc.php
- No code changes since 19.07.80
* Thu Jul 25 2019 wbauer@tmo.at
- Update to 19.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-beta.php
- Changes since 3.0.5:
  * yakuake web site due to be killed off in favour of kde.org/applications
  * [Yakuake] add blur effect support
  * [Yakuake] Use the svg icons instead of the png icons for the default theme (kde#397590)
  * Remove forcing the initial dir to QDir::homePath() (kde#396036)
  * Add DesktopEntry to notifyrc
  * [Yakuake] Improve customization
  * Remove double scrollbar in appearance settings
  * Fix Skin validation when installed from KNS (kde#395012)
  * Add option to restore fullscreen state of the window
  * Use correct variable type
  * Add shortcuts as default shortcuts (kde#401244)
  * Use KWindowSystem to determine which display system is in use
  * Fix KIcon -> QIcon porting bug
  * Use KMainWindow instead of QMainWindow (kde#398425)
  * Fix minor EBN issues and typos
- Update URL
- Remove %%post/%%postun sections, the package doesn't install
  shared libraries
- Make lang package optional
- Run spec-cleaner
* Wed Mar 28 2018 wbauer@tmo.at
- Update to 3.0.5
  * Improved Wayland support.
  * Yakuake's window title now always matches what's shown in its
    title bar.
  * Fixed button icons in the 'Appearance' settings page.
  * Yakuake now installs a D-Bus service file. This allows calling
    its D-Bus methods even when Yakuake is not running yet- it will
    then be started implicitly.
  * Fixed a crash due to a missing bounds check in the
    'sessionAtTab' D-Bus method.
  * Fixed a type marshalling issue with the 'addSession' D-Bus
    method that caused a noisy warning when using it via qdbus.
  * Yakuake now depends on KDE Frameworks 5.29 or higher.
- Drop 0001-Revert-Removed-usage-to-deprecated-interface.patch,
  Leap 42.2 is no longer supported
- Use cmake() syntax for BuildRequires
- Mark license files as %%license
* Wed Apr  5 2017 wbauer@tmo.at
- Update to 3.0.4
  * Fixed build on Qt 5.7.
- Add 0001-Revert-Removed-usage-to-deprecated-interface.patch to
  fix build on Leap 42.2 and lower
* Fri Mar 31 2017 wbauer@tmo.at
- Update to 3.0.3
  * Fixed Yakuake sometimes showing up in the Task Manager.
  * Much improved Wayland support on Plasma 5.
  * Added a security warning when using the runCommand DBus API (as
    recently added to KDE Konsole as well).
  * Switched to a different API for getting the user home path to
    avoid blocking on network logins.
  * The bell notification event now uses the correct Plasma 5 sound
    file name instead of an old KDE 4 one that may not be present.
  * Fixed standard CLI arguments like --help and --version.
  * Code cleanups, e.g. porting away from deprecated API.
  * Updated AppStream metadata.
- Drop yakuake-appdata-xml-desktop-ref.patch, fixed upstream
* Sat Nov  5 2016 hrvoje.senjan@gmail.com
- We need at least KF 5.15.0
* Mon Aug  8 2016 hrvoje.senjan@gmail.com
- Use the right macro for the appdata location
* Fri Jul 15 2016 badshah400@gmail.com
- Add yakuake-appdata-xml-desktop-ref.patch: fix the .desktop file
  referenced in the appdata.xml: yakuake.desktop ->
  org.kde.yakuake.desktop.
* Thu Mar  3 2016 tittiatcoke@gmail.com
- Update to 3.0.2
  * Also install the AppData file.
* Thu Mar  3 2016 tittiatcoke@gmail.com
- Update to 3.0.1
  * Fixed installation and integratin of hicolor application icon
* Thu Mar  3 2016 tittiatcoke@gmail.com
- Update to 3.0
  * Yakuake was ported to KDE Frameworks 5 and Qt 5
  * A new default skin follows the Plasma 5 Breeze design
- Drop yakuake-2.9.9_no-close.patch
* Sun Oct  4 2015 wbauer@tmo.at
- Require konsole4-part on Leap too
* Tue May 19 2015 hrvoje.senjan@gmail.com
- On openSUSE > 13.2 Require konsole4-part
* Sun Apr 19 2015 mpluskal@suse.com
- Update project url
- Use url for source
- Use post/postun scriplets to update desktop database
- Cleanup spec file with spec-cleaner
* Mon Jun 24 2013 hrvoje.senjan@gmail.com
- Fix typo in yakuake-2.9.9_no-close.patch
* Mon Apr  8 2013 peter@rmk2.org
- Add an option for keeping the window open after the last session closes.
  * This is a patch for bko#308850, as per upstream in git commit 4655fb0a.
* Sat Oct 20 2012 tittiatcoke@gmail.com
- Update to version 2.9.9
  * Yakuake now sports a standard KDE "Configure Notifications..."
    item in its menu.
  * It is now possible to monitor sessions (or individual terminals
    within them) for activity or silence.
  * Support for Get Hot New Stuff for skins has been added.
  * Yakuake now automatically retracts after the last open tab
    closes.
  * A number of default keyboard shortcuts have been changed to
    reestablish consistency with Konsole, which introduced changed
    defaults in KDE Software Compilation v4.6.
  * Invoking the window manager maximization feature now results in
    a Yakuake window with 100%% width and height instead of the
    unresized window getting moved to the top-left corner of the
    screen. However, restore is not supported as it doesn't easily
    fit with Yakuake's window size state model.
  * Tweaks to the code Yakuake uses to make itself the active window
    when invoked should improve compatibility with more window
    managers, particularly xfwm.
  * The D-Bus API has been expanded further to cover the new activity
    and silence monitoring options, as well as with additional
    methods related to retrieving information about the keyboard
    input enabled state for sessions and terminals.
  * The "Help" button was removed from the configuration dialog since
    there currently is no handbook included.
  * Fixed errors in the tab stop order in several pages of the
    configuration dialog.
  * Fixed the message shown on stderr when Yakuake is already running
    to refer to toggling rather than opening the window, since that
    is what a repeated execution actually does - if the window is
    already open, it will be closed at this time.
  * Code cleanups, including porting away from recently deprecated
    KDE Platform APIs for future-compatibility.
* Mon Nov 28 2011 ctrippe@opensuse.org
- Recommend and not only suggest the lang package
* Mon Sep 12 2011 toddrme2178@gmail.com
- Split lang package (fix for RPMLINT warning)
- Cleaned up spec file formatting
* Mon Aug 22 2011 mlin@novell.com
- Do not obsoletes itself(fix RPMLINT warning)
* Sat Jan 29 2011 tittiatcoke@gmail.com
- Update to version 2.9.8:
  * Added a new "Ask the window manager to perform the animation"
    option to the animation settings (only shown if Yakuake is
    running in a KDE Plasma Workspace v4.6 or newer). If this option
    is enabled (it is by default) and the KDE Desktop Effect
    "Sliding Popups" is enabled as well, the animation will be
    performed by KDE's window manager KWin, for much improved
    smoothness on many systems.
  * Added keyboard shortcuts to attempt to grow the active terminal
    in the left, right, top or bottom direction by 10px, as well
    as D-Bus calls to attempt to grow any particular terminal by a
    given amount of pixels in one of these directions.
  * Skin authors can now control whether the title bar text is set
    in a bold weight or not with the 'bold' key in the 'Text' group
    of title.skin.
  * Fixed a bug causing the "Keep above other windows" preference
    not to be respected immediately when toggling the "Keep window
    open when it loses focus" preference from the title bar or the
    main menu.
  * The contents of the "Screen" sub-menu in the main menu now get
    updated when the number of screens attached to the system changes.
* Sat Jul 17 2010 beineri@opensuse.org
- update to version 2.9.7:
  * Fixed quit action bypassing the "Confirm quit when more than
    one session is open" setting.
  * When "Prevent Closing" is toggled for a tab an appropriate icon
    will now be shown on the tab label. The icon can be provided by
    the skin, or, if the skin does not provide one, it will be
    procured from the system icon theme.
  * Thanks to API improvements in the KDE libraries in KDE SC 4.4 a
    KNotify notification is now used for announcing that Yakuake was
    started success-fully
  * Middle-clicking a tab closes it now, consistent with other apps.
  * Tabs can now also be dragged using middle-mouse, again for
    consistency with many other KDE apps.
  * Fixed a bug where dragging an inactive tab to a new position on
    the tab bar would show the tab as selected after the drop, but
    the terminal area wouldn't actually show corresponding terminal(s).
  * Fixed a bug causing the empty area of the tab bar to become
    draggable as if if was the last tab that had been clicked.
  * Fixed a bug causing the title bar corner images of a theme not
    to be shown when they don't have an alpha channel.
  * Fixed a bug causing the window to appear at a distance away from
    the top edge of the screen matching the height of a panel at the
    top edge of another screen in a multi-screen setup.
* Sat Jun 20 2009 beineri@opensuse.org
- update requirement on konsole
* Tue May 19 2009 beineri@opensuse.org
- update to version 2.9.6:
  * Fixed interactive rename of sessions not working reliably
  * Updated the application icon in the bottom-left corner graphic
  * Updated icon for default skin in configuration dialog's skin
* Mon May 11 2009 beineri@opensuse.org
- update to version 2.9.5:
  * Added a new framework to display notifications (and potentially
    other information) on top of the terminals.
  * Added an option to visually indicate the newly-focussed terminal
    when moving focus in a session with multiple terminals
  * Added a feature to disable keyboard input for all or individual
    terminals in a session.
  * Added a feature to lock a session to prevent it from being closed
  * Added support for moving tabs on the tab bar by drag and drop.
  * Added an option to open the application window after program start.
  * Improved graphics for window state lock button in default skin.
  * Added a slightly improved version of the application icon
  * Added D-Bus interfaces for splitting and other new interfaces
  * Several bug fixes
* Sun Sep 21 2008 stbinner@suse.de
- require kde4-konsole (bnc#422066)
* Sun Sep 21 2008 stbinner@suse.de
- require kdebase3 (bnc#422066)
* Sun Sep 21 2008 stbinner@suse.de
- update to version 2.9.4, fourth bug fix release of KDE4 port
* Tue Feb 26 2008 crrodriguez@suse.de
- use find_lang macro
* Sun Jan 27 2008 stbinner@suse.de
- update to new upstream version 2.8.1:
  - Added an option to control whether the Yakuake window keeps
    above other windows.
  - Improved experience for non-KDE users by disabling KRootPixmap-
    based pseudo-translucency for them. Gets rid of rendering errors
    with skins that make use of the alpha channel. Replaced by
    configurable skin background color.
  - Fix leftover gap below the window at 100%% height or in
    fullscreen mode.
  - Added option to automatically open the Yakuake window when the
    pointer touches the screen edge it lives on.
* Fri Oct  5 2007 stbinner@suse.de
- update to new upstream version 2.8:
  - Made the new behavior of the Open/Retract action focussing an
    already open Yakuake window optional.
  - The Xinerama screen setting is now updated when the window is
    moved to a different screen using facilities outside of Yakuake
    itself, such as the new shortcuts provided by Lubos Lunak's
    Xinerama Improvements patchset for KWin 3.5.x. The window size
    and position get updated to fit the new bounding box accordingly.
  - Initial session tab label naming is now consistent with Konsole.
    Instead of naively incrementing the shell number, the lowest
    available number is used.
  - Swapped horizontal & vertical split actions for consistency with Kate.
  - Added slotSessionName() and slotSessionName(int session_id) DCOP Calls.
  - Added sessionIdList() and terminalIdList(int session_id) DCOP calls.
  - Naming consistency improvements in the DCOP interface.
  - Added more What's This help in the config dialog.
  - Minor interface wording improvements.
  - Greatly expanded translation coverage.
* Fri Sep  7 2007 dkukawka@suse.de
- updated patches:
  - yakuake-fix_Accesskey_handling_v2.diff: fix b.n.c #307273,
    fixed missplaced check for Settings::popup()
* Tue May 15 2007 dkukawka@suse.de
- added patches:
  - yakuake-fix_Accesskey_handling.diff for b.n.c #272147 to change
    handling of Accesskey settings. Ask always for input key if
    there is no key set and added some KConfig::sync() calls.
* Sun May  6 2007 dkukawka@suse.de
- updated to new upstream beta version 2.8-beta1:
  * changelog to long please check ChangeLog file
* Wed May 24 2006 adrian@suse.de
- fix build for < 10.1
* Mon Mar 27 2006 dkukawka@suse.de
- updated to new upstream version 2.7.5:
  - Further translations have been added.
  - Yakuake no longer spawns login shells in new sessions.
  - A keyboard shortcut to rename the selected session has been
    added.
  - The default keyboard shortcuts and their names are now
    consistent with Konsole.
  - A bug that led to the tab bar not updating after a
    slotSelectSession DCOP call was issued has been fixed.
  - A bug that could lead to the slotRenameSession DCOP call
    failing to set a session label after an older session had been
    closed has been fixed.
  - Upon attempting to set an all-whitespace session label, the
    label will now fall back to its prior setting rather than a
    default label.
  - Yakuake will now display a warning before quitting the
    application with multiple tabs open.
* Sun Mar 19 2006 dkukawka@suse.de
- updated to new upstream version 2.7.4 :
  - A bug in the Makefiles that led to the configure script being
    run twice has been fixed.
  - The source code is now localizable. First translations are
    included.
  - A bug that could result in a crash on quit has been fixed.
  - A bug that could prevent the first line in a new session from
    being used up to the full width of the terminal has been fixed.
  - The COLORTERM environment variable is now being set in new
    sessions, triggering the color detection of Midnight Commander.
  - The default session labels are now consistent with Konsole.
  - Whitespace at the beginning or end of session labels will now
    be trimmed.
  - Setting all-whitespace session labels is no longer possible.
* Wed Feb 15 2006 stbinner@suse.de
- add GenericName to .desktop file
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 18 2006 dkukawka@suse.de
- initial package (v2.7.3)
